# frozen_string_literal: true

Application.boot(:clients, namespace: true) do
  init do
    require 'cht-lib-fabric/helpers/graphql/http'
    require 'cht-lib-fabric/clients'
    require 'cht-lib-fabric/services'
    require 'role_management/clients/user_management_service'
    require 'role_management/clients/org_management_service'
  end

  start do |application|
    use :settings

    authorization_uri = target[:settings].authorization_uri
    target[:logger].debug("authorization URI: #{authorization_uri}")
    unless authorization_uri && !authorization_uri.empty?
      raise "Authorization service unconfigured: check setting value authorization_uri"
    end

    authorization_client = Platform::Clients::Authorization.new(::Platform::Helpers::GraphQL.http(authorization_uri))
    register(:authorization, authorization_client)

    flow_down_uri = target[:settings].flow_down_uri
    target[:logger].debug("flow-down URI: #{flow_down_uri}")
    unless flow_down_uri && !flow_down_uri.empty?
      raise "FlowDown service unconfigured: check setting value flowdown_uri"
    end

    flowdown_client = Platform::Clients::FlowDown.new(::Platform::Helpers::GraphQL.http(flow_down_uri))
    register(:flowdown, flowdown_client)

    org_management_uri = target[:settings].org_management_uri
    target[:logger].debug("Org Management URI: #{org_management_uri}")
    unless org_management_uri && !org_management_uri.empty?
      raise "Org Management service unconfigured: check setting value org_management_uri"
    end

    org_management_client = ::Platform::Helpers::GraphQL.http(org_management_uri)
    register(:org_management, ::RoleManagement::Clients::OrgManagement.new(org_management_client))

    user_management_uri = target[:settings].user_management_uri
    target[:logger].debug("User Management URI: #{user_management_uri}")
    unless user_management_uri && !user_management_uri.empty?
      raise "User Management service unconfigured: check setting value user_management_uri"
    end

    user_management_client = (::Platform::Helpers::GraphQL.http(user_management_uri))
    register(:user_management, ::RoleManagement::Clients::UserManagement.new(user_management_client))

    service_acct_client =
        ::Platform::Services::ServiceAccount.new(
            local_auth_uri: application[:settings].local_auth_uri,
            service_account: application[:settings].service_account,
            api_key: application[:settings].api_key
        )
    register(:service_acct, service_acct_client)

  end
end
