# frozen_string_literal: true

require 'dry/transaction'
require 'dry/system/container'
require 'dry/system/components'
require 'cht-lib-fabric/components'
require 'cht-lib-fabric/dry_transaction_step_adapters'
require 'singleton-client'

class Application < ::Dry::System::Container
  use(:env, inferrer: -> { (ENV['RACK_ENV'] || 'development').to_sym })

  vipEnv = (ENV['VIP_ENV'] || ENV['RACK_ENV'] || 'development').to_sym
  awsRegion = (ENV['AWS_REGION'] || 'us-east-1').to_sym

  configure do |config|
    config.name = SERVICE_NAME
    config.auto_register = %w[app]
  end
  load_paths!('app')

  %i[alert graphql i18n logger].each { |c| boot(c, from: :platform) }
  boot(:statsd, from: :platform) do
    configure do |config|
      config.namespace = "#{SERVICE_NAME}.#{SERVICE_TASK}"
    end
  end

  vip_env_with_region = vipEnv.to_s.eql?('development') ? vipEnv.to_s : (vipEnv.to_s + '-' + awsRegion.to_s)
  Sgtn.load_config('config/singleton.yml', vip_env_with_region)

  # If you use Kafka, uncomment the following:
  # boot(:karafka, from: :platform) do
  #   configure do |config|
  #     config.client_id = "#{SERVICE_NAME}-#{SERVICE_TASK}"
  #   end
  # end
  Transaction = ::Dry::Transaction(container: Application, step_adapters: ::Platform::DryTransactionStepAdapters)
end
